==> kea-docs-2.2.0-2-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/dir_c749baf520c234b64f40a0a0c9de62a0.js <==
var dir_c749baf520c234b64f40a0a0c9de62a0 =
[
    [ "d2_cfg_mgr.cc", "d1/d99/d2__cfg__mgr_8cc.html", null ],
    [ "d2_cfg_mgr.h", "d0/d80/d2__cfg__mgr_8h.html", "d0/d80/d2__cfg__mgr_8h" ],
    [ "d2_config.cc", "d4/d13/d2__config_8cc.html", "d4/d13/d2__config_8cc" ],
    [ "d2_config.h", "d1/db0/d2__config_8h.html", "d1/db0/d2__config_8h" ],
    [ "d2_log.cc", "dd/d78/d2__log_8cc.html", "dd/d78/d2__log_8cc" ],
    [ "d2_log.h", "dc/d8a/d2__log_8h.html", null ],
    [ "d2_messages.cc", "d7/d06/d2__messages_8cc.html", "d7/d06/d2__messages_8cc" ],
    [ "d2_messages.h", "d0/dab/d2__messages_8h.html", null ],
    [ "d2_simple_parser.cc", "d9/d39/d2__simple__parser_8cc.html", null ],
    [ "d2_simple_parser.h", "d1/d8c/d2__simple__parser_8h.html", [
      [ "isc::d2::D2SimpleParser", "d3/d85/classisc_1_1d2_1_1D2SimpleParser.html", "d3/d85/classisc_1_1d2_1_1D2SimpleParser" ]
    ] ],
    [ "d2_stats.cc", "d5/dc7/d2__stats_8cc.html", null ],
    [ "d2_stats.h", "dc/d16/d2__stats_8h.html", [
      [ "isc::d2::D2Stats", "d8/d94/classisc_1_1d2_1_1D2Stats.html", null ]
    ] ],
    [ "d2_tsig_key.cc", "d4/d1a/d2__tsig__key_8cc.html", null ],
    [ "d2_tsig_key.h", "d8/d8a/d2__tsig__key_8h.html", "d8/d8a/d2__tsig__key_8h" ],
    [ "d2_update_message.cc", "d6/d7c/d2__update__message_8cc.html", null ],
    [ "d2_update_message.h", "db/de9/d2__update__message_8h.html", "db/de9/d2__update__message_8h" ],
    [ "d2_zone.cc", "d3/d7f/d2__zone_8cc.html", "d3/d7f/d2__zone_8cc" ],
    [ "d2_zone.h", "d0/d9d/d2__zone_8h.html", "d0/d9d/d2__zone_8h" ],
    [ "dns_client.cc", "d2/daf/dns__client_8cc.html", [
      [ "isc::d2::DNSClientImpl", "d5/d30/classisc_1_1d2_1_1DNSClientImpl.html", "d5/d30/classisc_1_1d2_1_1DNSClientImpl" ]
    ] ],
    [ "dns_client.h", "d2/dfa/dns__client_8h.html", "d2/dfa/dns__client_8h" ],
    [ "nc_trans.cc", "d0/d71/nc__trans_8cc.html", null ],
    [ "nc_trans.h", "dd/d74/nc__trans_8h.html", "dd/d74/nc__trans_8h" ]
];

==> kea-docs-3.0.0-6-x86_64.pkg.tar.zst: usr/share/doc/kea/devel/dir_c749baf520c234b64f40a0a0c9de62a0.js <==
var dir_c749baf520c234b64f40a0a0c9de62a0 =
[
    [ "d2_cfg_mgr.cc", "d1/d99/d2__cfg__mgr_8cc.html", null ],
    [ "d2_cfg_mgr.h", "d0/d80/d2__cfg__mgr_8h.html", "d0/d80/d2__cfg__mgr_8h" ],
    [ "d2_config.cc", "d4/d13/d2__config_8cc.html", "d4/d13/d2__config_8cc" ],
    [ "d2_config.h", "d1/db0/d2__config_8h.html", "d1/db0/d2__config_8h" ],
    [ "d2_log.cc", "dd/d78/d2__log_8cc.html", "dd/d78/d2__log_8cc" ],
    [ "d2_log.h", "dc/d8a/d2__log_8h.html", null ],
    [ "d2_messages.cc", "d7/d06/d2__messages_8cc.html", "d7/d06/d2__messages_8cc" ],
    [ "d2_messages.h", "d0/dab/d2__messages_8h.html", null ],
    [ "d2_simple_parser.cc", "d9/d39/d2__simple__parser_8cc.html", null ],
    [ "d2_simple_parser.h", "d1/d8c/d2__simple__parser_8h.html", "d1/d8c/d2__simple__parser_8h" ],
    [ "d2_stats.cc", "d5/dc7/d2__stats_8cc.html", null ],
    [ "d2_stats.h", "dc/d16/d2__stats_8h.html", "dc/d16/d2__stats_8h" ],
    [ "d2_tsig_key.cc", "d4/d1a/d2__tsig__key_8cc.html", null ],
    [ "d2_tsig_key.h", "d8/d8a/d2__tsig__key_8h.html", "d8/d8a/d2__tsig__key_8h" ],
    [ "d2_update_message.cc", "d6/d7c/d2__update__message_8cc.html", null ],
    [ "d2_update_message.h", "db/de9/d2__update__message_8h.html", "db/de9/d2__update__message_8h" ],
    [ "d2_zone.cc", "d3/d7f/d2__zone_8cc.html", "d3/d7f/d2__zone_8cc" ],
    [ "d2_zone.h", "d0/d9d/d2__zone_8h.html", "d0/d9d/d2__zone_8h" ],
    [ "dns_client.cc", "d2/daf/dns__client_8cc.html", "d2/daf/dns__client_8cc" ],
    [ "dns_client.h", "d2/dfa/dns__client_8h.html", "d2/dfa/dns__client_8h" ],
    [ "nc_trans.cc", "d0/d71/nc__trans_8cc.html", null ],
    [ "nc_trans.h", "dd/d74/nc__trans_8h.html", "dd/d74/nc__trans_8h" ]
];
